#!/bin/sh
# Run HALCON phyCAM scripts on your Arm-based Linux computer.
# Copyright (C) 2021 PHYTEC, Mainz, Germany

platform=$(uname -m)
case "$platform" in
  aarch64)
    arch="aarch64-linux"
  ;;
  armv7l)
    arch="armv7a-linux"
  ;;
  x86_64)
    echo "HPeek is available for Arm-based platforms only." >&2
    echo "" >&2
    exit 1
  ;;
  *)
    echo "Your platform $platform is not supported." >&2
    echo "" >&2
    exit 1
  ;;
esac

echo ""
echo " If the first start after reboot, an initialize of camera is necessary"
echo " ====================================================================="
echo " 1 = monochrome camera @ Cam_0 port"
echo " 2 = color camera @ CAM_0 port"
echo " 3 = initialize done"
read SET_MEDIA_CTL
echo " Your select = $SET_MEDIA_CTL"
case $SET_MEDIA_CTL in
  "1") ./init_bw_phyCAM-M_v4l_device.sh ;;
  "2") ./init_col_phyCAM-M_v4l_device.sh ;;
  "3") ;;
  *) ;;
esac

#if [ ! -f "camera_device.txt" ]; then
#  echo " Could not find camera_device.txt." >&2
#  echo " Please initialized you connected camera." >&2
#  echo " Check if the connected camera is activated in the bootloader?" >&2
#  echo "" >&2
#  exit 1
#fi

echo " Choose the example script"
echo " ========================="
echo " 1 = show monochrome live stream"
echo " 2 = show color live stream"
echo " 3 = save a jpg monochrome image"
echo " 4 = save a jpg color image"
echo " 5 = optical flow, read from monochrome camera"
echo " 6 = optical flow, read from color camera"
read SET_MEDIA_CTL
echo " Your select = $SET_MEDIA_CTL"
case $SET_MEDIA_CTL in
  "1") script=grabb_bw_and_show_phyCAM_via_gst.hdev ;;
  "2") script=grabb_col_and_show_phyCAM_via_gst.hdev ;;
  "3") script=grabb_bw_and_save-jpg_phyCAM_via_gst.hdev ;;
  "4") script=grabb_col_and_save-jpg_phyCAM_via_gst.hdev ;;
  "5") script=bw_optical_flow.hdev ;;
  "6") script=col_optical_flow.hdev ;;
  *) script=grabb_bw_and_show_phyCAM_via_gst.hdev ;;
esac

if [ ! -f $script ]; then
  echo " Could not find '$script'." >&2
  echo " Please change to the HALCON examples/phytec directory and run ./start.sh there." >&2
  echo "" >&2
  exit 1
fi

source ./init_display.sh

echo " Running '../../bin/$arch/hpeek $script'"
../../bin/$arch/hpeek $script
